# TypeScript libraries for MCAP

[MCAP](https://mcap.dev/) is a modular container format and logging library for pub/sub messages with arbitrary message serialization. It is primarily intended for use in robotics applications, and works well under various workloads, resource constraints, and durability requirements.

The following NPM packages are provided for use with JavaScript and TypeScript:

- **@mcap/core** – low-level readers and writers
- **@mcap/support** – support for well-known compression formats
- **@mcap/nodejs** – support for Node.js environment
- **@mcap/browser** – support for browser environment
